@@ -366,6 +366,13 @@ if cmp -s SortOrderFileSeparatorTest01.result SortOrderFileSeparatorTest01.norm
 then echo "PASSED" >> TestResults;
 else echo $'\x1b[1m\x1b[31mFAILED\x1b[0m' >> TestResults;
 fi
+#This tests skipping of the first record
+msort -j -q -d '/' -t w -Z SkipFirstRecordTest01.data > SkipFirstRecordTest01.result
+echo -n "SkipFirstRecordTest01		" >> TestResults;
+if cmp -s SkipFirstRecordTest01.result SkipFirstRecordTest01.norm
+then echo "PASSED" >> TestResults;
+else echo $'\x1b[1m\x1b[31mFAILED\x1b[0m' >> TestResults;
+fi
 #This tests sorting on string length, with a secondary lexicographic sort.
 msort -j -q -l -n 1 -c s -n 1 < StringLengthTest01.data > StringLengthTest01.result
 echo -n "StringLengthTest01		" >> TestResults;
