@@ -4,7 +4,7 @@
 #if defined HAVE_LOCALE_H && defined HAVE_SETLOCALE && defined HAVE_WCSXFRM
 #define LOCALE_SORT_ORDER
 #endif
-#if defined HAVE_LOCALE_H && defined HAVE_SETLOCALE && defined HAVE_LIBINTL_H
+#if defined HAVE_LOCALE_H && defined HAVE_SETLOCALE && defined HAVE_GETTEXT
 #define LOCALE_GETTEXT
 #endif
 
