@@ -8,8 +8,9 @@ struct dstr {
 
 #ifndef DSTR
 extern int FillDynamicString(struct dstr *, wchar_t *);
+extern void FreeDynamicString (struct dstr *);
 extern void InitializeDynamicString (struct dstr *);
-extern struct dstr *MakeDyanmicString (struct dstr *,wchar_t *);
+extern struct dstr *MakeDynamicString (wchar_t *);
 extern  void AppendToDyanmicString (struct dstr *,const wchar_t *);
 #endif
 
