@@ -1,4 +1,4 @@
-/* Time-stamp: <2008-09-30 18:37:17 poser> */
+/* Time-stamp: <2009-02-25 17:40:37 poser> */
 
 /*
  * Copyright (C) 1993-2008 William J. Poser (billposer@alum.mit.edu).
@@ -63,10 +63,13 @@ PrintGeneralFlags(FILE *fp)
   fprintf(fp,_("\t-I,--invert-globally\tInvert sense of comparisons globally\n"));
   fprintf(fp,_("\t-Q,--check-only\t\tCheck whether input is sorted. Generate no output.\n\t\t\t\tExit status is 0 if input is sorted, 11 if not.\n"));
   fprintf(fp,_("\t-u,--unicode-normalization <Normalization Mode>\n"));
-  fprintf(fp,_("\t\tc NFC canonical decomposition then composition (default)\n"));
-  fprintf(fp,_("\t\td NFD canonical decomposition\n"));
-  fprintf(fp,_("\t\tn no normalization\n"));
+  fprintf(fp,_("\t\tc NFC  canonical decomposition then composition (default)\n"));
+  fprintf(fp,_("\t\td NFD  canonical decomposition\n"));
+  fprintf(fp,_("\t\tC NFKC compatibility decomposition then composition\n"));
+  fprintf(fp,_("\t\tD NFKD compatibility decomposition\n"));
+  fprintf(fp,_("\t\tn      no normalization\n"));
   fprintf(fp,_("\t-P,--random-seed <seed>\n"));
+  fprintf(fp,_("\t-Z,--skip-first-record\n"));
   fprintf(fp,_("\t-1,--in  <Input File Name>\n"));
   fprintf(fp,_("\t-2,--out <Output File Name>\n"));
   fprintf(fp,_("\t-j,--suppress-log\tSuppress log output\n"));
@@ -176,14 +179,17 @@ PrintGeneralFlags(FILE *fp)
   fprintf(fp,_("\t-m                    End of line is marked by Carriage Return (0x0D)\n"));
   fprintf(fp,_("\t-I                    Invert sense of comparisons globally\n"));
   fprintf(fp,_("\t-P <seed>             Set the random number generator seed.\n"));
+  fprintf(fp,_("\t-Z,--skip-first-record\n"));
   fprintf(fp,_("\t-1 <Input File Name>\n"));
   fprintf(fp,_("\t-2 <Output File Name>\n"));
   fprintf(fp,_("\t-j                    Suppress log output\n"));
   fprintf(fp,_("\t-q                    Be quiet - do not chat while working\n"));
   fprintf(fp,_("\t-u <Normalization Mode>\n"));
-  fprintf(fp,_("\t\tc NFC canonical decomposition then composition (default)\n"));
-  fprintf(fp,_("\t\td NFD canonical decomposition\n"));
-  fprintf(fp,_("\t\tn no normalization\n"));
+  fprintf(fp,_("\t\tc NFC  canonical decomposition then composition (default)\n"));
+  fprintf(fp,_("\t\td NFD  canonical decomposition\n"));
+  fprintf(fp,_("\t\tC NFKC compatibility decomposition then composition\n"));
+  fprintf(fp,_("\t\tD NFKD compatibility decomposition\n"));
+  fprintf(fp,_("\t\tn      no normalization\n"));
   fputc('\n',fp);				
 }
 
@@ -273,11 +279,13 @@ PrintDefaults(FILE *fp)
    fprintf(fp,_("    Initial number of records       %4d\n"),DEFMAXRECORDS);
    fprintf(fp,_("    Presence of key                 obligatory\n"));
    fprintf(fp,_("    Record type                     double end-of-line terminated block\n"));
+   fprintf(fp,_("    Skip first record               no\n"));
    fprintf(fp,_("    Sense of sort                   forward\n"));	
    fprintf(fp,_("    Date format                     y-m-d (International Date Format)\n"));
    fprintf(fp,_("    Sort order                      numerical Unicode order\n"));
    fprintf(fp,_("    Sort type                       lexicographic\n"));
    fprintf(fp,_("    Algorithm                       quicksort\n"));
+   fprintf(fp,_("    Unicode normalization           NFC\n"));
    fprintf(fp,"\n");
 }
 
