@@ -1,4 +1,4 @@
-/* Time-stamp: <2007-10-05 02:00:44 poser> */
+/* Time-stamp: <2008-11-02 12:10:41 poser> */
 /*
  * Copyright (C) 2005-2007 William J. Poser.
  * This program is free software; you can redistribute it and/or modify
@@ -60,23 +60,23 @@ ReportReadError(
   switch (c)
     { 
     case UTF8_NOTENOUGHBYTES:
-      fprintf(fp,gettext("Truncated UTF-8 sequence encountered at record %ld, byte %ld.\n"),
+      fprintf(fp,_("Truncated UTF-8 sequence encountered at record %ld, byte %ld.\n"),
 	      RecordNumber, ByteCnt);
       exit(1);
       break;
     case UTF8_BADINCODE:
-      fprintf(fp,gettext("Invalid UTF-8 code encountered at record %ld, byte %ld.\n"),
+      fprintf(fp,_("Invalid UTF-8 code encountered at record %ld, byte %ld.\n"),
 	      RecordNumber, ByteCnt);
       ExplicateBadUTF8(fp,rp);
       exit(1);
       break;
     case UTF8_BADOUTCODE:
-      fprintf(fp,gettext("Encountered invalid Unicode at record %ld, byte %ld.\n"),
+      fprintf(fp,_("Encountered invalid Unicode at record %ld, byte %ld.\n"),
 	      RecordNumber, ByteCnt);
       exit(1);
       break;
     case UTF8_IOERROR:
-      snprintf(msg,MSGSIZE-1,gettext("Error reading input at record %ld, byte %ld.\n"),
+      snprintf(msg,MSGSIZE-1,_("Error reading input at record %ld, byte %ld.\n"),
 	       RecordNumber,ByteCnt);
       perror(msg);
       exit(1);
