@@ -1,7 +1,7 @@
-/* Time-stamp: <2008-04-10 16:15:56 poser> */
+/* Time-stamp: <2008-10-19 00:14:01 poser> */
 
 /*
- * Copyright (C) 2007 William J. Poser.
+ * Copyright (C) 2007, 2008 William J. Poser.
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of version 3 of the GNU General Public License
  * as published by the Free Software Foundation.
@@ -17,7 +17,7 @@
  * or go to the web page:  http://www.gnu.org/licenses/gpl.txt.
  */
 
-/* These are ancillary functions for interpreting ISO8601 time/date stamps */
+/* These are functions for interpreting ISO8601 time/date stamps */
 
 #include "config.h"
 #include "compdefs.h"
@@ -176,3 +176,84 @@ StripTimeDateSeparators(char *s, char *tloc) {
   *tgt = '\0';
   return(tloc-cnt);
 }
+
+/* 
+ * This produces a value that is suitable for ordering dates and times.
+ * It is NOT accurate for computing differences between dates and times
+ * because the conversion of dates to days is not exact. For simplicity's
+ * sake it treats years as containing 366 days and months as all containing
+ * 31 days.
+ *
+ * This handles both basic and extended formats. It also permits an optional leading sign,
+ * restricts the year to four digits.
+ */
+#define DTITYPE unsigned long
+#define SECONDSINDAY (60*60*24)
+int
+GetISO8601Key(wchar_t *field, DOUBLE *key)
+{
+  unsigned int year = 0;
+  unsigned int month =0;
+  unsigned int day = 0;
+  unsigned int hour = 0;
+  unsigned int minute = 0;
+  unsigned int second = 0;
+
+  long TZOffset;		/* Number of seconds to add to normalize to UTC */
+  DTITYPE Days;
+  DTITYPE DaySeconds;
+  int f1, f2;
+  char *cfield;
+  char *nscfield;		/* cfield without optional leading sign */
+  char * Tloc;
+  short err;
+  int YearSign = 1;
+
+  extern UTF8 * ws2u8(wchar_t *);
+
+  cfield = (char *) ws2u8(field);
+  Tloc = strchr(cfield,'T');
+  if(!Tloc) {free(cfield);return(ERROR);}
+  Tloc = StripTimeDateSeparators(cfield,Tloc);
+  err=0;
+  TZOffset = ExtractTimeZone(((UTF8 *)Tloc)+1,&err);
+  if(err) return(ERROR);
+
+  if(cfield[0] == '-') {
+    YearSign = -1;
+    nscfield = cfield + 1;
+  }
+  else if(cfield[0] == '+') nscfield = cfield + 1;
+  else nscfield = cfield;
+
+  f1=sscanf(nscfield,"%4u%2u%2uT%2u%2u.%2u", &year,&month,&day,&hour,&minute,&second);
+  if(f1 != 6) {
+    f2=sscanf(nscfield,"%4u%2u%2uT%2u%2u", &year,&month,&day,&hour,&minute);
+    if(f2 != 5) {free(cfield);return(ERROR);}
+  }
+  free(cfield);
+  if(month < 0 || day < 0) return (ERROR);
+  if(month > 12) return (ERROR);
+  if(day > 31) return (ERROR);
+  if(hour < 0 || minute < 0 || second < 0) return (ERROR);
+  if(hour > 24) return(ERROR);
+  if(minute > 60 || second > 60) return (ERROR);
+
+#ifdef UNNECESSARY
+  /* 
+   * If making actual date calculations, the following is necessary as per the spec.
+   * That is, 2007-04-05T24:00 is the same instant as 2007-04-06T00:00
+   * For our purposes it is unnecessary as it has no effect on ordering,
+   * so we'd might as well be slightly more efficient and omit it.
+   */
+  if ((hour == 24) && (minute == 0)) {
+    hour = 0;
+    day += 1;
+  }
+#endif
+
+  Days = (DTITYPE) ( (366 * (DTITYPE) year) + (31 * month) + day);
+  DaySeconds = (DTITYPE) (((((DTITYPE) hour * 60) + (DTITYPE) minute) * 60) + (DTITYPE) second);
+  *key = (DOUBLE) ((DOUBLE) YearSign * ( ( (DOUBLE)Days * (DOUBLE)SECONDSINDAY) + (DOUBLE)DaySeconds + (DOUBLE)TZOffset));
+  return(SUCCESS);
+}
