@@ -1,11 +1,10 @@
-/* $Id: limits.h,v 1.7 2003/12/15 07:05:06 poser Exp poser $ */
 
 /*
  * This first section contains constants which can be changed at will.
  */
 
 /* Default initial maximum records to sort */
-#define DEFMAXRECORDS	8192
+#define DEFMAXRECORDS	10240
 
 /* Initial size of input text buffer */
 #define INPUTTEXTSIZEINIT 8192
@@ -16,18 +15,19 @@
 /* Maximum length of numeric string */
 #define MAXDOUBLELEN 256
 
-/* These can't be changed since they reflect the Unicode standard */
+
+/* The following can't be changed freely since they reflect the Unicode standard */
 #define MAXUNICODE 0x1FFFFF
 #define MAXBMP     0x00FFFF
 
 #define NPU_FIRSTMULTIGRAPHCODE 0xD800
 #define NPU_MAXMULTIGRAPHCODE 0xDFFF
-#define NPU_MAXMULTIGRAPHS 2048
+#define NPU_MAXMULTIGRAPHS (NPU_MAXMULTIGRAPHCODE - NPU_FIRSTMULTIGRAPHCODE + 1)
 
 #define BMP_FIRSTMULTIGRAPHCODE 0xE000
 #define BMP_MAXMULTIGRAPHCODE 0xF8FF
-#define BMP_MAXMULTIGRAPHS (0xF8FF - 0xE000 + 1)
+#define BMP_MAXMULTIGRAPHS (BMP_MAXMULTIGRAPHCODE - BMP_FIRSTMULTIGRAPHCODE + 1)
 
 #define FUL_FIRSTMULTIGRAPHCODE 0xF0000
 #define FUL_MAXMULTIGRAPHCODE 0x10FFFD
-#define FUL_MAXMULTIGRAPHS (0x10FFFD - 0xF0000 + 1)
+#define FUL_MAXMULTIGRAPHS (FUL_MAXMULTIGRAPHCODE - FUL_FIRSTMULTIGRAPHCODE + 1)
