@@ -1,7 +1,7 @@
-/* Time-stamp: <2008-10-19 00:14:16 poser> */
+/* Time-stamp: <2009-06-01 20:08:16 poser> */
 
 /*
- * Copyright (C) 1993-2008 William J. Poser.
+ * Copyright (C) 1993-2009 William J. Poser.
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of version 3 of the GNU General Public License
  * as published by the Free Software Foundation.
@@ -93,7 +93,7 @@ DumpExclusions(unsigned char *exct,long exctsize,FILE *fp)
  */
 
 int
-Exclude(wchar_t *str, int len, wchar_t *exct)
+Exclude(wchar_t *str, int len, unsigned char *exct)
 {
   int i;
   int cnt;
@@ -630,7 +630,7 @@ EvalEscapes(wchar_t *s)
  */
 
 int
-ExcludeChar(wchar_t *str, wchar_t **out, int len, wchar_t *exct)
+ExcludeChar(wchar_t *str, wchar_t **out, int len, unsigned char *exct)
 {
   int i;
   int cnt;
@@ -709,3 +709,17 @@ UTF32 * NormalizeString(UTF32 *s, int32_t *ResultLength, UNormalizationMode type
 }
 
 #endif
+
+/* Reverse a plain C string in place */
+void ReverseString(char *s) {
+  int i, j;
+  int len;
+  char t;
+
+  len = strlen(s);
+  for (i = 0, j = len-1; i < len/2; i++, j--) {
+    t = s[i];
+    s[i] = s[j];
+    s[j] = t;
+  }
+}
